﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;
using IWshRuntimeLibrary;
using System.IO;

namespace SciLor_s_Mashed_Runner {
    public partial class frmMashed : Form {

        private const String MASHED_EXE = "MFL.exe";
        private const String MASHED_SAVE = ""; //@"save\";

        private static IconFile[] MASHED_ICOS = {
            new IconFile(@"TOASTART\Common\PANEL\NFLRed.png"),
            new IconFile(@"TOASTART\Common\PANEL\NFLBluejay.png"),
            new IconFile(@"TOASTART\Common\PANEL\NFLGold.png"),
            new IconFile(@"TOASTART\Common\PANEL\NFLMelon.png"),
            new IconFile(@"TOASTART\Common\PANEL\NFLPink.png"),
            new IconFile(@"TOASTART\Common\PANEL\NFLShadow.png"),
                                              };

        private const String MASHED_ICO = @"TOASTART\Common\PANEL\NFLRed.png";
        private const String MASHED_ICO_SMALL = "mashed.ICO";

        public frmMashed() {
            InitializeComponent();
            cmbLanguage.Items.Add(new Language("English", "English", 0));
            cmbLanguage.Items.Add(new Language("Français", "French", 1));
            cmbLanguage.Items.Add(new Language("Deutsch", "German", 2));
            cmbLanguage.Items.Add(new Language("Español", "Spanish", 3));
            cmbLanguage.Items.Add(new Language("Português", "Portuguese", 4));

            cmbLanguage.SelectedIndex = Properties.Settings.Default.Language;
            if (Properties.Settings.Default.Path.Length == 0)
                Properties.Settings.Default.Path = System.IO.Path.GetDirectoryName(GetExePath()) + "\\";
            txtPath.Text = Properties.Settings.Default.Path;
            txtPath.Text += MASHED_EXE;

            for (int i=0; i<MASHED_ICOS.Length; i++) {
                IconFile icon = MASHED_ICOS[i];
                cmbIcon.Items.Add(icon);
            }

            if (Properties.Settings.Default.Icon.Length == 0) {
                Properties.Settings.Default.Icon = MASHED_ICO;
            }
            foreach (Object obj in cmbIcon.Items) {
                if (obj.Equals(new IconFile(Properties.Settings.Default.Icon))) {
                    cmbIcon.SelectedItem = obj;
                }
            }

            loadICO();
        }

        private String GetExePath() {
            String path = System.Reflection.Assembly.GetExecutingAssembly().CodeBase;
            if (path.StartsWith("file:///")) {
                path = path.Substring("file:///".Length);
            }
            path = path.Replace('/', '\\');
            return path;
        }

        private void btnRunMashed_Click(object sender, EventArgs e) {
            run(false, false, true);
        }

        private void btnRunVideo_Click(object sender, EventArgs e) {
            run(true, false, false);
        }

        private void btnRunController_Click(object sender, EventArgs e) {
            run(false, true, false);
        }

        private bool checkMashedExe() {
            if (!System.IO.File.Exists(Properties.Settings.Default.Path + MASHED_EXE)) {
                MessageBox.Show(MASHED_EXE + " " + "not found" + "\r\n" +
                    "Please copy this application into the Mashed - Fully Loaded directory" + "\r\n" +
                    "or select the right path to its executable.",
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return false;
            }
            return true;
        }

        private void run(bool video, bool control, bool exit) { //-VS0 -CS0 -L2
            if (!checkMashedExe()) return;
            this.Enabled = false;

            int lang = 0;
            if (cmbLanguage.SelectedItem != null) {
                Language langObj = (Language)cmbLanguage.SelectedItem;
                lang = langObj.Id;
            }

            Process p = new Process();
            p.StartInfo.FileName = Properties.Settings.Default.Path + MASHED_EXE;
            p.StartInfo.Arguments = "-VS" + bool2int(video) + " " + "-CS" + bool2int(control) + " " + "-L" + lang;
            p.StartInfo.WorkingDirectory = Properties.Settings.Default.Path + MASHED_SAVE;
            p.Start();

            if (exit) {
                this.Close();
                Application.Exit();
            } else {
                p.WaitForExit();
                this.Enabled = true;
                this.WindowState = FormWindowState.Minimized;
                this.WindowState = FormWindowState.Normal;
            }
        }
        private int bool2int(bool value) {
            if (value) return 1;
            return 0;
        }

        private void cmbLanguage_SelectedIndexChanged(object sender, EventArgs e) {
            Properties.Settings.Default.Language = cmbLanguage.SelectedIndex;
            Properties.Settings.Default.Save();
        }

        private void btnPath_Click(object sender, EventArgs e) {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = MASHED_EXE + "|" + MASHED_EXE;
            ofd.CheckFileExists = true;
            ofd.FileName = MASHED_EXE;

            if (ofd.ShowDialog() == System.Windows.Forms.DialogResult.OK) {
                if (ofd.FileName.EndsWith(MASHED_EXE)) {
                    txtPath.Text = ofd.FileName;
                    Properties.Settings.Default.Path = txtPath.Text.Remove(txtPath.TextLength - MASHED_EXE.Length);
                    Properties.Settings.Default.Save();
                    loadICO();
                }
            }
        }
        private void loadICO() {
            String path = Properties.Settings.Default.Path + Properties.Settings.Default.Icon;
            if (!System.IO.File.Exists(path)) {
                return;
            }

            btnRunMashed.Image = new Bitmap(path);
            btnRunVideo.Image = btnRunMashed.Image;
            btnRunController.Image = btnRunMashed.Image;

            btnRunMashed.ImageAlign = ContentAlignment.TopLeft;
            btnRunVideo.ImageAlign = ContentAlignment.MiddleLeft;
            btnRunController.ImageAlign = ContentAlignment.BottomLeft;

            this.ShowIcon = false;
            this.Icon = null;
            this.ShowIcon = true;
            this.Icon = Icon.FromHandle(new Bitmap(path).GetHicon());

            FileStream fs = new FileStream(Path.GetDirectoryName(GetExePath()) + "\\" +
                "icon" + cmbIcon.SelectedItem + ".ico", FileMode.Create);
            this.Icon.Save(fs);
            fs.Close();
        }

        private void btnShortcut_Click(object sender, EventArgs e) {
            SaveFileDialog sfd = new SaveFileDialog();
            sfd.DefaultExt = ".lnk";
            sfd.FileName = "Mashed Fully Loaded.lnk";
            sfd.Filter = "Shortcut (*.lnk)|*.lnk";
            sfd.ValidateNames = true;
            if (sfd.ShowDialog() == System.Windows.Forms.DialogResult.OK && sfd.FileName != null) {
                WshShellClass wshShell = new WshShellClass();
                IWshShortcut link = (IWshShortcut)(wshShell.CreateShortcut(sfd.FileName));
                link.TargetPath = GetExePath();
                link.Description = "Starts Mashed Fully Loaded";
                if (checkMashedExe()) 
                    link.IconLocation = Path.GetDirectoryName(GetExePath()) + "\\" +
                        "icon" + cmbIcon.SelectedItem + ".ico";
                link.Save();
            }
        }

        private void cmbIcon_SelectedIndexChanged(object sender, EventArgs e) {
            Properties.Settings.Default.Icon = (cmbIcon.SelectedItem as IconFile).path;
            Properties.Settings.Default.Save();
            loadICO();
        }
    }
}
